Library Reference
==================================

.. automodule:: glitter_sdk

``driver``
----------

.. autoclass:: GlitterClient
    :members:

    .. automethod:: __init__

.. automodule:: glitter_sdk.driver

.. autoclass:: DataBase
    :members:
.. autoclass:: Chain
    :members:  tx_search,block_search,block,status
.. autoclass:: Admin
    :members:
